@@ -129,6 +129,8 @@ class ResourceSqueezingMiddleware(object):
                     registry.cache.clear()
 
             # process document body
+            if response.charset is None:
+                return
             changed, expires, body = self.process_html(
                 accept_request_data, request.host_url,
                 request.path, response.unicode_body)
@@ -201,8 +203,8 @@ class ResourceSqueezingMiddleware(object):
             ttl, changed = self.update_elements(
                 elements, selections, tree, host, uri, cache) or changed
 
-            if expires is None or ttl < expires:
-                expires = ttl                
+            if expires is None or ttl is None or ttl < expires:
+                expires = ttl
                 
         return changed, expires, XMLSerializer(tree, lxml.html.tostring)
 
@@ -232,7 +234,7 @@ class ResourceSqueezingMiddleware(object):
                 if resource is None or src not in selection:
                     continue
 
-                if expires is None or ttl < expires:
+                if expires is None or ttl is None or ttl < expires:
                     expires = ttl
 
                 # if this is the last item in the selection,
@@ -264,7 +266,7 @@ def update_style_tag(element, url):
     
     """
     
-    m = re_stylesheet_import.match(element.text)
+    m = re_stylesheet_import.match(element.text or u"")
     if m is not None:
         before = m.group(1)
         path = m.group(2)
@@ -278,7 +280,7 @@ def get_link_url(element):
     return element.attrib['href']
 
 def get_style_url(element):
-    m = re_stylesheet_import.match(element.text)
+    m = re_stylesheet_import.match(element.text or u"")
     if m is not None:
         return m.group(2)
     
